@@ -19,33 +19,32 @@
 #include "registry.h"
 
 Registry::Registry(){
-	// Loading libq4wine-core.so
+    // Loading libq4wine-core.so
 #ifdef RELEASE
     libq4wine.setFileName(_CORELIB_PATH_);
 #else
     libq4wine.setFileName("../q4wine-lib/libq4wine-core");
 #endif
 
-	if (!libq4wine.load()){
-		libq4wine.load();
-	}
+    if (!libq4wine.load()){
+        libq4wine.load();
+    }
 
-	// Getting corelib calss pointer
-	CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
-	CoreLib.reset((corelib *)CoreLibClassPointer(true));
-	return;
+    // Getting corelib calss pointer
+    CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
+    CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
+    return;
 }
 
-Registry::Registry(QString prefixPath){
-	regfile.append(prefixPath);
-	regfile.append("/");
-
-	return;
+Registry::Registry(QString prefixPath): Registry(){
+    regfile.append(prefixPath);
+    regfile.append("/");
+    return;
 }
 
 bool Registry::init(){
-	regfile_image="REGEDIT4";
-	return true;
+    regfile_image="REGEDIT4";
+    return true;
 }
 
 void Registry::append(QString reg_keys){
@@ -100,7 +99,7 @@ void Registry::unsetPath(QString path, const QString hkey){
 	return;
 }
 
-bool Registry::exec(QObject *parent, QString prefix_path, QString prefix_name){
+bool Registry::exec(QObject *parent, QString prefix_path, QString prefix_name, QString post_run){
 
 	//This function wrights regfile_image into file, then run regedit.exe and import this file.
 	//Also, clean files before end
@@ -134,6 +133,8 @@ bool Registry::exec(QObject *parent, QString prefix_path, QString prefix_name){
     ExecObject execObj;
     execObj.cmdargs = QString("C:/temp/%1.reg").arg(file_name);
     execObj.execcmd = "regedit.exe";
+    if (!post_run.isEmpty())
+        execObj.postrun = post_run;
 
     bool ret = CoreLib->runWineBinary(execObj, prefix_name, false);
 
@@ -214,6 +215,8 @@ QStringList Registry::readExcludedKeys(const QString sysfile, const QString path
 		QByteArray line = file.readLine();
 
 		if ((readFlag) && (!line.trimmed().isEmpty())){
+			if (line.startsWith("#time"))
+				continue;
 			QList<QByteArray> key = line.trimmed().split('=');
 			int index = keys.indexOf(key.at(0));
 			if (index==-1){
