@@ -65,7 +65,7 @@ int main(int argc, char *argv[])
     //! This is needed for libq4wine-core.so import;
     typedef void *CoreLibPrototype (bool);
     CoreLibPrototype *CoreLibClassPointer;
-    std::auto_ptr<corelib> CoreLib;
+    std::unique_ptr<corelib> CoreLib;
     QLibrary libq4wine;
 
     // Loading libq4wine-core.so
@@ -82,7 +82,7 @@ int main(int argc, char *argv[])
 
     // Getting corelib calss pointer
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
-    CoreLib.reset((corelib *)CoreLibClassPointer(true));
+    CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     if (!CoreLib.get()){
         QErr<<"[EE] Cannot load shared library."<<endl;
