@@ -33,7 +33,9 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
 
     // Getting corelib calss pointer
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
-    CoreLib.reset((corelib *)CoreLibClassPointer(true));
+    CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
+
+    qRegisterMetaTypeStreamOperators<QList<int> >("QList<int>");
 
     this->prefixName=prefixName;
     wine64=false;
@@ -49,7 +51,7 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
 
     splitter->setSizes(size);
 
-    std::auto_ptr<QVBoxLayout> vlayout (new QVBoxLayout);
+    std::unique_ptr<QVBoxLayout> vlayout (new QVBoxLayout);
     vlayout->addWidget(splitter.release());
     vlayout->setMargin(0);
     vlayout->setSpacing(0);
@@ -79,8 +81,17 @@ FakeDriveSettings::FakeDriveSettings(QString prefixName, QWidget * parent, Qt::W
     cmdGetWineDesktopPic->installEventFilter(this);
     cmdGetWineDesktopMus->installEventFilter(this);
     cmdGetWineDesktopVid->installEventFilter(this);
+    cmdGetPostRunBin->installEventFilter(this);
 
-
+    QSettings settings(APP_SHORT_NAME, "default");
+    settings.beginGroup("LastItems");
+    txtPostRunBin->addItems(settings.value("prefix").toStringList());
+#if QT_VERSION >= 0x050000
+    txtPostRunBin->setCurrentText("");
+#else
+    txtPostRunBin->setEditText("");
+#endif
+    settings.endGroup();
 
 }
 
@@ -101,6 +112,9 @@ void FakeDriveSettings::optionsTree_itemClicked ( QTreeWidgetItem *item, int){
     } else if (itemText==tr("Wine Browsers")){
         optionsStack->setCurrentIndex(0);
         tabwGeneral->setCurrentIndex(2);
+    } else if (itemText==tr("Scripts")){
+        optionsStack->setCurrentIndex(0);
+        tabwGeneral->setCurrentIndex(3);
     } else if (itemText==tr("Video")){
         optionsStack->setCurrentIndex(1);
         tabwVideo->setCurrentIndex(0);
@@ -165,6 +179,7 @@ void FakeDriveSettings::loadDefaultPrefixSettings(){
 }
 
 void FakeDriveSettings::cmdOk_Click(){
+
 #ifdef DEBUG
     qDebug()<<"[ii] Saveing fake drive settings";
 #endif
@@ -239,13 +254,13 @@ void FakeDriveSettings::cmdOk_Click(){
     userDir.append(QString::fromUtf8(getenv("USER")));
 
     if (list.count()==5){
-                desktopFolder = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(0).split("\\\\").last()));
-                desktopMusic = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(1).split("\\\\").last()));
-                desktopPictures = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(2).split("\\\\").last()));
-                desktopDocuments = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(4).split("\\\\").last()));
-                desktopVideos = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(3).split("\\\\").last()));
+        desktopFolder = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(0).split("\\\\").last()));
+        desktopMusic = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(1).split("\\\\").last()));
+        desktopPictures = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(2).split("\\\\").last()));
+        desktopDocuments = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(4).split("\\\\").last()));
+        desktopVideos = QString("%1/%2").arg(userDir).arg(CoreLib->decodeRegString(list.at(3).split("\\\\").last()));
     } else {
-         QMessageBox::warning(this, tr("Error"), tr("Cannot read desktop paths!"));
+        QMessageBox::warning(this, tr("Error"), tr("Cannot read desktop paths!"));
         this->reject();
         return;
     }
@@ -281,7 +296,7 @@ void FakeDriveSettings::cmdOk_Click(){
 
     if (listWineDrives->count()>0){
         for (int i=0; i<listWineDrives->count(); i++){
-            std::auto_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->item(i)));
+            std::unique_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->item(i)));
 
             if (item.get()){
                             QString driveLink = QString("%1/%2").arg(prefixPath).arg(item->getLetter().toLower());
@@ -455,7 +470,7 @@ void FakeDriveSettings::cmdOk_Click(){
 #endif
 
     for (int i=0; i<listWineDrives->count(); i++){
-        std::auto_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->item(i)));
+        std::unique_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->item(i)));
 #ifdef DEBUG
         qDebug()<<"[ii] Wizard::get DriveListWidgetItem for "<<listWineDrives->item(i)->text();
 #endif
@@ -756,7 +771,22 @@ void FakeDriveSettings::cmdOk_Click(){
     qDebug()<<"[ii] Wizard::run registry import";
 #endif
 
-        if (registry.exec(this, db_prefix.getPath(prefixName), prefixName)){
+    QSettings settings(APP_SHORT_NAME, "default");
+
+    settings.beginGroup("LastItems");
+    QStringList last_items;
+    for (int index = 0; index < txtPostRunBin->count(); index++){
+        QString item_text = txtPostRunBin->itemText(index);
+        if ((!last_items.contains(item_text)) and (!item_text.isEmpty()))
+            last_items << txtPostRunBin->itemText(index);
+    }
+    QString curr_text = txtPostRunBin->currentText();
+    if ((!curr_text.isEmpty()) and (!curr_text.isNull()) and (!last_items.contains(curr_text)))
+        last_items.append(txtPostRunBin->currentText());
+    settings.setValue("prefix", QVariant::fromValue(last_items));
+    settings.endGroup();
+
+    if (registry.exec(this, db_prefix.getPath(prefixName), prefixName, curr_text)){
         CoreLib->createPrefixDBStructure(prefixName);
 #ifndef _OS_DARWIN_
         if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
@@ -766,13 +796,15 @@ void FakeDriveSettings::cmdOk_Click(){
 #endif
 
 #ifdef DEBUG
-    qDebug()<<"[ii] Wizard::done";
+        qDebug()<<"[ii] Wizard::done";
 #endif
-    QTimer::singleShot(3000, this, SLOT(waitForWineEnd()));
-        } else {
-            QApplication::restoreOverrideCursor();
-            reject();
+        QTimer::singleShot(3000, this, SLOT(waitForWineEnd()));
+    } else {
+        if (!this->txtPostRunBin->currentText().isEmpty()){
         }
+        QApplication::restoreOverrideCursor();
+        reject();
+    }
     return;
 }
 
@@ -804,7 +836,7 @@ void FakeDriveSettings::cmdCancel_Click(){
 void FakeDriveSettings::cmdHelp_Click(){
     QString rawurl;
 
-    std::auto_ptr<QTreeWidgetItem> item (optionsTree->currentItem());
+    std::unique_ptr<QTreeWidgetItem> item (optionsTree->currentItem());
     if (!item.get()){
          item.release();
          return;
@@ -818,6 +850,8 @@ void FakeDriveSettings::cmdHelp_Click(){
         rawurl = "07-fake-drive-settings.html#colors";
     } else if (itemText==tr("Wine Browsers")){
         rawurl = "07-fake-drive-settings.html#winebrowsers";
+    } else if (itemText==tr("Scripts")){
+        rawurl = "07-fake-drive-settings.html#scripts";
     } else if (itemText==tr("Video")){
         rawurl = "07-fake-drive-settings.html#video";
     } else if (itemText=="Direct3D" && item->parent()->text(0)==tr("Video")){
@@ -866,6 +900,7 @@ void FakeDriveSettings::loadThemeIcons(){
     cmdGetWineDesktopPic->setIcon(CoreLib->loadIcon("document-open"));
     cmdGetWineDesktopMus->setIcon(CoreLib->loadIcon("document-open"));
     cmdGetWineDesktopVid->setIcon(CoreLib->loadIcon("document-open"));
+    cmdGetPostRunBin->setIcon(CoreLib->loadIcon("document-open"));
     return;
 }
 
@@ -893,7 +928,7 @@ void FakeDriveSettings::cmdJoystickAdd_Click(){
 }
 
 void FakeDriveSettings::cmdJoystickDel_Click(){
-    std::auto_ptr<QListWidgetItem> item (listJoystickAxesMappings->currentItem());
+    std::unique_ptr<QListWidgetItem> item (listJoystickAxesMappings->currentItem());
     if (!item.get())
         return;
 
@@ -902,7 +937,7 @@ void FakeDriveSettings::cmdJoystickDel_Click(){
 }
 
 void FakeDriveSettings::cmdWineDriveEdit_Click(){
-    std::auto_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->currentItem()));
+    std::unique_ptr<DriveListWidgetItem> item (dynamic_cast<DriveListWidgetItem*>(listWineDrives->currentItem()));
 
     if (!item.get())
         return;
@@ -935,7 +970,7 @@ void FakeDriveSettings::cmdWineDriveAdd_Click(){
 
     WineDriveDialog drevedialog(drives);
     if (drevedialog.exec()==QDialog::Accepted){
-        std::auto_ptr<DriveListWidgetItem> item (new DriveListWidgetItem(listWineDrives));
+        std::unique_ptr<DriveListWidgetItem> item (new DriveListWidgetItem(listWineDrives));
         item->setDrive(drevedialog.getLetter(), drevedialog.getPath(), drevedialog.getType());
         listWineDrives->addItem(item.release());
     }
@@ -943,7 +978,7 @@ void FakeDriveSettings::cmdWineDriveAdd_Click(){
 }
 
 void FakeDriveSettings::cmdWineDriveDel_Click(){
-    std::auto_ptr<QListWidgetItem> item (listWineDrives->currentItem());
+    std::unique_ptr<QListWidgetItem> item (listWineDrives->currentItem());
     if (!item.get())
         return;
 
@@ -959,7 +994,7 @@ void FakeDriveSettings::cmdWineDriveDel_Click(){
 
 void FakeDriveSettings::loadSettings(){
     QString prefixPath = db_prefix.getPath(prefixName);
-    std::auto_ptr<DriveListWidgetItem> item;
+    std::unique_ptr<DriveListWidgetItem> item;
 
     if (prefixPath.isEmpty()){
         qDebug()<<" [EE] Cant get prefix path: "<<prefixName;
@@ -1309,7 +1344,7 @@ void FakeDriveSettings::loadDefaultSettings(){
 
     txtOwner->setText(QString::fromUtf8(getenv("USER")));
 
-    std::auto_ptr<DriveListWidgetItem> item;
+    std::unique_ptr<DriveListWidgetItem> item;
     item.reset(new DriveListWidgetItem(listWineDrives));
     item->setDrive("C:", "../drive_c", "auto");
     listWineDrives->addItem(item.release());
@@ -1327,30 +1362,54 @@ void FakeDriveSettings::loadDefaultSettings(){
     item->setDrive("Z:", "/", "auto");
     listWineDrives->addItem(item.release());
 
-    txtWineDesktop->setText(QString("%1/desktop-integration/Desktop").arg(prefixPath));
-    txtWineDesktopDoc->setText(QString("%1/desktop-integration/").arg(prefixPath));
-    txtWineDesktopMus->setText(QString("%1/desktop-integration/").arg(prefixPath));
-    txtWineDesktopPic->setText(QString("%1/desktop-integration/").arg(prefixPath));
-    txtWineDesktopVid->setText(QString("%1/desktop-integration/").arg(prefixPath));
+    QString wineDesktopPath = CoreLib->getSetting("DesktopIntegration", "WineDesktop", false, QString("%1/desktop-integration/Desktop").arg(prefixPath)).toString();
+    if (wineDesktopPath.isEmpty()){
+        wineDesktopPath = QString("%1/desktop-integration/Desktop").arg(prefixPath);
+    }
+    txtWineDesktop->setText(wineDesktopPath);
 
-        if (!dir.exists(txtWineDesktopDoc->text())){
-            if (!dir.mkdir(txtWineDesktopDoc->text())){
-                QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
-                QApplication::restoreOverrideCursor();
-                reject();
-            }
+    wineDesktopPath = CoreLib->getSetting("DesktopIntegration", "WineDesktopDoc", false, QString("%1/desktop-integration/").arg(prefixPath)).toString();
+    if (wineDesktopPath.isEmpty()){
+        wineDesktopPath = QString("%1/desktop-integration/Desktop").arg(prefixPath);
+    }
+    txtWineDesktopDoc->setText(wineDesktopPath);
+
+    wineDesktopPath = CoreLib->getSetting("DesktopIntegration", "WineDesktopMus", false, QString("%1/desktop-integration/").arg(prefixPath)).toString();
+    if (wineDesktopPath.isEmpty()){
+        wineDesktopPath = QString("%1/desktop-integration/").arg(prefixPath);
+    }
+    txtWineDesktopMus->setText(wineDesktopPath);
+
+    wineDesktopPath = CoreLib->getSetting("DesktopIntegration", "WineDesktopPic", false, QString("%1/desktop-integration/").arg(prefixPath)).toString();
+    if (wineDesktopPath.isEmpty()){
+        wineDesktopPath = QString("%1/desktop-integration/").arg(prefixPath);
+    }
+    txtWineDesktopPic->setText(wineDesktopPath);
+
+    wineDesktopPath = CoreLib->getSetting("DesktopIntegration", "WineDesktopVid", false, QString("%1/desktop-integration/").arg(prefixPath)).toString();
+    if (wineDesktopPath.isEmpty()){
+        wineDesktopPath = QString("%1/desktop-integration/").arg(prefixPath);
+    }
+    txtWineDesktopVid->setText(wineDesktopPath);
+
+    if (!dir.exists(txtWineDesktopDoc->text())){
+        if (!dir.mkdir(txtWineDesktopDoc->text())){
+            QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
+            QApplication::restoreOverrideCursor();
+            reject();
         }
+    }
 
-        if (!dir.exists(txtWineDesktop->text())){
-            if (!dir.mkdir(txtWineDesktop->text())){
-                QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
-                QApplication::restoreOverrideCursor();
-                reject();
-            }
+    if (!dir.exists(txtWineDesktop->text())){
+        if (!dir.mkdir(txtWineDesktop->text())){
+            QMessageBox::warning(this, tr("Error"), tr("Cannot create dir: %1").arg(prefixPath));
+            QApplication::restoreOverrideCursor();
+            reject();
         }
+    }
 
-        // We need to wait for wine while it writes .reg files....
-        QTimer::singleShot(1000, this, SLOT(waitForWine()));
+    // We need to wait for wine while it writes .reg files....
+    QTimer::singleShot(1000, this, SLOT(waitForWine()));
 }
 
 bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
@@ -1371,7 +1430,7 @@ bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
                 options = QFileDialog::DontUseNativeDialog | QFileDialog::DontResolveSymlinks;
 
         if (obj->objectName().right(3)=="Bin"){
-            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(),   "All files (*)", 0, options);
+            file = QFileDialog::getOpenFileName(this, tr("Open File"), QDir::homePath(), "All files (*)", 0, options);
         } else {
             file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath(),  options);
         }
@@ -1382,19 +1441,32 @@ bool FakeDriveSettings::eventFilter(QObject *obj, QEvent *event){
             file = QFileDialog::getExistingDirectory(this, tr("Open Directory"), QDir::homePath());
         }
 #endif
-
         if (!file.isEmpty()){
             QString a;
             a.append("txt");
             a.append(obj->objectName().right(obj->objectName().length()-6));
 
-            std::auto_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(a));
-            if (lineEdit.get()){
-                lineEdit->setText(file);
+            if (QString("%1").arg(findChild<QWidget *>(a)->metaObject()->className()) == "QComboBox") {
+                std::unique_ptr<QComboBox> cbEdit (findChild<QComboBox *>(a));
+                if (cbEdit.get()){
+#if QT_VERSION >= 0x050000
+                    cbEdit->setCurrentText(file);
+#else
+                    cbEdit->setEditText(file);
+#endif
+                } else {
+                    qDebug("Error");
+                }
+                cbEdit.release();
             } else {
-                qDebug("Error");
+                std::unique_ptr<QLineEdit> lineEdit (findChild<QLineEdit *>(a));
+                if (lineEdit.get()){
+                    lineEdit->setText(file);
+                } else {
+                    qDebug("Error");
+                }
+                lineEdit.release();
             }
-            lineEdit.release();
 
             if (obj==cmdGetWineDesktop){
                 txtWineDesktopDoc->setText(file);
