@@ -34,6 +34,11 @@
 #include <QVBoxLayout>
 #include <QInputDialog>
 #include <QTimer>
+#include <QStringListModel>
+#include <QMetaType>
+#include <QVariant>
+
+Q_DECLARE_METATYPE(QList<int>)
 
 #include "src/core/database/prefix.h"
 #include "src/core/database/icon.h"
@@ -90,13 +95,13 @@ private:
    bool eventFilter(QObject *obj, QEvent *event);
    bool wine64;
 
-    std::auto_ptr<QSplitter> splitter;
+    std::unique_ptr<QSplitter> splitter;
 
     //! This is need for libq4wine-core.so import.
     QLibrary libq4wine;
     typedef void *CoreLibPrototype (bool);
     CoreLibPrototype *CoreLibClassPointer;
-    std::auto_ptr<corelib> CoreLib;
+    std::unique_ptr<corelib> CoreLib;
 
     //! Database prefix class defenition.
     Prefix db_prefix;
