@@ -40,7 +40,7 @@ class AppDBScrollWidget : public QScrollArea
 {
 	Q_OBJECT
 public:
-	AppDBScrollWidget(QWidget * parent = 0);
+    explicit AppDBScrollWidget(QWidget * parent = 0);
 	void addSearchWidget(const WineAppDBInfo appinfo);
 	void addTestWidget(const WineAppDBInfo appinfo);
 	void addVersionFrame(QList<WineAppDBCategory> list, QString frame_caption, short int action);
@@ -57,8 +57,8 @@ private:
 	void gotoCommentId(int id);
 	void hideAll(void);
 
-	std::auto_ptr<QWidget> contentWidget;
-	std::auto_ptr<QVBoxLayout> contentLayout;
+	std::unique_ptr<QWidget> contentWidget;
+	std::unique_ptr<QVBoxLayout> contentLayout;
 
 };
 
