@@ -34,13 +34,13 @@ IconListToolbar::IconListToolbar(QWidget *parent) :
 
     // Getting corelib calss pointer
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
-    CoreLib.reset((corelib *)CoreLibClassPointer(true));
+    CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     this->sort_order = CoreLib->getSetting("IconWidget", "IconSort", false, D_SORT_TYPE_BY_DATE_ASC).toInt();
     this->view_mode = CoreLib->getSetting("IconWidget", "ViewMode", false, D_VIEW_MODE_ICON).toInt();
     this->createActions();
 
-    std::auto_ptr<QToolBar> toolBar (new QToolBar(this));
+    std::unique_ptr<QToolBar> toolBar (new QToolBar(this));
 
     toolBar->setIconSize(QSize(24, 24));
     toolBar->addAction(searchClear.get());
@@ -60,7 +60,7 @@ IconListToolbar::IconListToolbar(QWidget *parent) :
     toolBar->addAction(sortAlpha.get());
     toolBar->addAction(sortCreation.get());
 
-    std::auto_ptr<QVBoxLayout> layout (new QVBoxLayout(this));
+    std::unique_ptr<QVBoxLayout> layout (new QVBoxLayout(this));
     layout->setSpacing(0);
     layout->setContentsMargins(0,0,0,0);
     layout->addWidget(toolBar.release());
@@ -90,10 +90,12 @@ void IconListToolbar::createActions(){
 
     zoomIn.reset(new QAction(CoreLib->loadIcon("zoom-in"), tr("Zoom In"), this));
     zoomIn->setStatusTip(tr("Zoom In"));
+    zoomIn->setShortcut(Qt::Key_Plus);
     connect(zoomIn.get(), SIGNAL(triggered()), this, SLOT(zoomIn_Click()));
 
     zoomOut.reset(new QAction(CoreLib->loadIcon("zoom-out"), tr("Zoom Out"), this));
     zoomOut->setStatusTip(tr("Zoom Out"));
+    zoomOut->setShortcut(Qt::Key_Minus);
     connect(zoomOut.get(), SIGNAL(triggered()), this, SLOT(zoomOut_Click()));
 
     sortAlpha.reset(new QAction(this));
