@@ -110,7 +110,7 @@ private:
       QLibrary libq4wine;
       typedef void *CoreLibPrototype (bool);
       CoreLibPrototype *CoreLibClassPointer;
-      std::auto_ptr<corelib> CoreLib;
+      std::unique_ptr<corelib> CoreLib;
 
 private slots:
       void showContents(QString filterString);
