@@ -34,13 +34,13 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
 
     // Getting corelib calss pointer
     CoreLibClassPointer = (CoreLibPrototype *) libq4wine.resolve("createCoreLib");
-    CoreLib.reset((corelib *)CoreLibClassPointer(true));
+    CoreLib.reset(static_cast<corelib *>(CoreLibClassPointer(true)));
 
     this->sort_order = CoreLib->getSetting("WinetricksWidget", "IconSort", false, D_SORT_TYPE_BY_DATE_ASC).toInt();
 
     this->createActions();
 
-    std::auto_ptr<QToolBar> treeToolBar (new QToolBar(this));
+    std::unique_ptr<QToolBar> treeToolBar (new QToolBar(this));
     treeToolBar->setIconSize(QSize(24, 24));
 
     cbPrefixes.reset(new QComboBox(this));
@@ -58,17 +58,21 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
     treeWidget->header()->close();
     connect (treeWidget.get(), SIGNAL(currentItemChanged (QTreeWidgetItem *, QTreeWidgetItem *)), this, SLOT(treeWidget_currentItemChanged (QTreeWidgetItem *, QTreeWidgetItem *)));
 
-    treeWidget->installEventFilter(this);
+    //treeWidget->installEventFilter(this);
 
-    std::auto_ptr<QToolBar> iconsToolBar (new QToolBar(this));
+    std::unique_ptr<QToolBar> iconsToolBar (new QToolBar(this));
     iconsToolBar->setIconSize(QSize(24, 24));
 
     searchField.reset (new QLineEdit(this));
     connect(searchField.get(), SIGNAL(textChanged(QString)), this, SLOT(searchFilterChange(QString)));
 
     //connect(searchField.get(), SIGNAL(returnPressed()), this, SLOT(appdbSearch_Click()));
+
     iconsToolBar->addAction(searchClear.get());
     iconsToolBar->addWidget(searchField.get());
+    iconsToolBar->addAction(zoomIn.get());
+    iconsToolBar->addAction(zoomOut.get());
+    iconsToolBar->addSeparator();
     iconsToolBar->addAction(sortAlpha.get());
 
     listWidget.reset(new QListWidget(this));
@@ -77,8 +81,10 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
     listWidget->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
     listWidget->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
     listWidget->setMovement(QListView::Static);
-    int nSize = CoreLib->getSetting("IconWidget", "IconSize", false, 32).toInt();
     listWidget->setViewMode(QListView::ListMode);
+    //listWidget->installEventFilter(this);
+
+    int nSize = CoreLib->getSetting("WinetricksWidget", "IconSize", false, 32).toInt();
     listWidget->setGridSize(QSize());
     listWidget->setIconSize(QSize(nSize, nSize));
     listWidget->setWrapping(false);
@@ -87,9 +93,9 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
     connect(listWidget.get(), SIGNAL(itemDoubleClicked (QListWidgetItem *)), this, SLOT(itemDoubleClicked (QListWidgetItem *)));
     connect(listWidget.get(), SIGNAL(currentItemChanged (QListWidgetItem *, QListWidgetItem *)), this, SLOT(currentItemChanged (QListWidgetItem *, QListWidgetItem *)));
 
-    std::auto_ptr<QWidget> treeFrameWidget(new QWidget(this));
+    std::unique_ptr<QWidget> treeFrameWidget(new QWidget(this));
 
-    std::auto_ptr<QVBoxLayout> layout (new QVBoxLayout(this));
+    std::unique_ptr<QVBoxLayout> layout (new QVBoxLayout(this));
     layout->setSpacing(0);
     layout->setContentsMargins(0,0,0,0);
     layout->addWidget(treeToolBar.release());
@@ -97,7 +103,7 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
 
     treeFrameWidget->setLayout(layout.release());
 
-    std::auto_ptr<QWidget> iconsFrameWidget(new QWidget(this));
+    std::unique_ptr<QWidget> iconsFrameWidget(new QWidget(this));
 
     layout.reset(new QVBoxLayout(this));
     layout->setSpacing(0);
@@ -115,7 +121,7 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
     infoName.reset(new QLabel(QString("%1:\n\%2:").arg(tr("Name")).arg(tr("Description")), this));
     infoName->setTextInteractionFlags(Qt::TextSelectableByMouse);
     infoName->setWordWrap(true);
-    std::auto_ptr<QFrame> frame(new QFrame(this));
+    std::unique_ptr<QFrame> frame(new QFrame(this));
 
     layout.reset(new QVBoxLayout(this));
     layout->setSpacing(3);
@@ -146,21 +152,23 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
 }
 
 PrefixConfigWidget::~PrefixConfigWidget(){
-    treeWidget.release();
-    listWidget.release();
-    infoName.release();
-
+    QSettings settings(APP_SHORT_NAME, "default");
     if (splitter->sizes().at(0) != splitter->sizes().at(1)){
-        QSettings settings(APP_SHORT_NAME, "default");
         settings.beginGroup("MainWindow");
         settings.setValue("splitterPrefixConfigSize0", splitter->sizes().at(0));
         settings.setValue("splitterPrefixConfigSize1", splitter->sizes().at(1));
         settings.endGroup();
-        settings.beginGroup("WinetricksWidget");
-        settings.setValue("IconSort", this->sort_order);
-        settings.endGroup();
     }
+
+    settings.beginGroup("WinetricksWidget");
+    settings.setValue("IconSort", this->sort_order);
+    settings.setValue("IconSize", this->listWidget->iconSize().height());
+    settings.endGroup();
+
     splitter.release();
+    treeWidget.release();
+    listWidget.release();
+    infoName.release();
 }
 
 void PrefixConfigWidget::createActions(){
@@ -185,6 +193,16 @@ void PrefixConfigWidget::createActions(){
         sortAlpha->setIcon(CoreLib->loadIcon("view-sort-ascending"));
     }
 
+    zoomIn.reset(new QAction(CoreLib->loadIcon("zoom-in"), tr("Zoom In"), this));
+    zoomIn->setStatusTip(tr("Zoom In"));
+    zoomIn->setShortcut(Qt::Key_Plus);
+    connect(zoomIn.get(), SIGNAL(triggered()), this, SLOT(zoomIn_Click()));
+
+    zoomOut.reset(new QAction(CoreLib->loadIcon("zoom-out"), tr("Zoom Out"), this));
+    zoomOut->setStatusTip(tr("Zoom Out"));
+    zoomOut->setShortcut(Qt::Key_Minus);
+    connect(zoomOut.get(), SIGNAL(triggered()), this, SLOT(zoomOut_Click()));
+
     return;
 }
 
@@ -193,7 +211,7 @@ void PrefixConfigWidget::createTree(){
     this->listWidget->clear();
 
     QList<ProviderItem> providers = db_sysconfig.getProviders();
-    std::auto_ptr<QTreeWidgetItem> prefixItem;
+    std::unique_ptr<QTreeWidgetItem> prefixItem;
     for (int i = 0; i < providers.size(); i++){
         prefixItem.reset(new QTreeWidgetItem(this->treeWidget.get()));
         prefixItem->setText(0, providers.at(i).name);
@@ -203,7 +221,7 @@ void PrefixConfigWidget::createTree(){
         QStringList subtypes = db_sysconfig.getProviderSubtypes(providers.at(i).id);
         for (int j = 0; j < subtypes.size(); j++){
             if (!subtypes.at(j).isEmpty()){
-                std::auto_ptr<QTreeWidgetItem> subPrefixItem (new QTreeWidgetItem(prefixItem.get(), 0));
+                std::unique_ptr<QTreeWidgetItem> subPrefixItem (new QTreeWidgetItem(prefixItem.get(), 0));
                 subPrefixItem->setText(0, QString("%1").arg(subtypes.at(j)));
                 subPrefixItem->setIcon(0, CoreLib->loadIcon("folder"));
                 subPrefixItem.release();
@@ -218,7 +236,7 @@ void PrefixConfigWidget::createTree(){
 
     for(int i=0; i < this->treeWidget.get()->topLevelItemCount(); i++)
     {
-        std::auto_ptr<QTreeWidgetItem> item(this->treeWidget.get()->topLevelItem(i));
+        std::unique_ptr<QTreeWidgetItem> item(this->treeWidget.get()->topLevelItem(i));
         if (item->text(0)==this->provider){
 
             this->treeWidget.get()->setCurrentItem(item.get());
@@ -249,7 +267,7 @@ void PrefixConfigWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int col
     if (!item->parent()){
         this->provider = item->text(0);
     } else {
-        std::auto_ptr<QTreeWidgetItem> p_item (item->parent());
+        std::unique_ptr<QTreeWidgetItem> p_item (item->parent());
         this->provider = p_item->text(0);
         this->subtype = item->text(0);
         p_item.release();
@@ -264,9 +282,10 @@ void PrefixConfigWidget::get_icons(){
     this->listWidget.get()->clear();
 
     QIcon defIcon = CoreLib->loadIcon("application-x-executable-script");
+    QIcon defIconInstalled = CoreLib->loadIcon("application-x-ms-dos-executable");
 
     QList<SysconfigItem> items = db_sysconfig.getItems(this->provider, this->subtype, this->sort_order, this->searchField->text());
-    std::auto_ptr<QListWidgetItem> iconItem;
+    std::unique_ptr<QListWidgetItem> iconItem;
     for (int i = 0; i < items.size(); i++){
         iconItem.reset(new QListWidgetItem(this->listWidget.get(), 0));
         if (this->subtype.isEmpty()){
@@ -302,7 +321,11 @@ void PrefixConfigWidget::get_icons(){
         } else {
             iconItem->setText(items.at(i).name);
             iconItem->setToolTip(items.at(i).desc);
-            iconItem->setIcon(defIcon);
+            if (items.at(i).is_installed) {
+                iconItem->setIcon(defIconInstalled);
+            } else {
+                iconItem->setIcon(defIcon);
+            }
         }
         iconItem.release();
     }
@@ -337,8 +360,9 @@ void PrefixConfigWidget::keyPressEvent ( QKeyEvent * event ){
     if (!item)
         return;
 
-    if (event->key() == Qt::Key_Return)
+    if (event->key() == Qt::Key_Return) {
         itemDoubleClicked(item);
+    }
 }
 
 void PrefixConfigWidget::currentItemChanged (QListWidgetItem *item, QListWidgetItem *){
@@ -425,23 +449,6 @@ void PrefixConfigWidget::itemDoubleClicked (QListWidgetItem *item){
     return;
 }
 
-bool PrefixConfigWidget::eventFilter(QObject *obj, QEvent *event)
- {
-     if (obj == this->treeWidget.get()) {
-         if (event->type() == QEvent::KeyPress) {
-             QKeyEvent *keyEvent = static_cast<QKeyEvent*>(event);
-
-             if (keyEvent->matches(QKeySequence::Delete)){
-                 return true;
-             }
-         } else {
-             return false;
-         }
-     }
-     // pass the event on to the parent class
-     return QWidget::eventFilter(obj, event);
- }
-
 void PrefixConfigWidget::setPrefix(QString prefix){
     this->cbPrefixes.get()->setCurrentIndex(cbPrefixes.get()->findText(prefix));
 }
@@ -451,6 +458,23 @@ void PrefixConfigWidget::searchClear_Click(){
     this->get_icons();
 }
 
+void PrefixConfigWidget::zoomIn_Click(){
+    QSize i_size = this->listWidget->iconSize();
+    if (i_size.height()){
+        int nSize = i_size.height()+8;
+        this->listWidget->setIconSize(QSize(nSize, nSize));
+    }
+}
+
+void PrefixConfigWidget::zoomOut_Click(){
+    QSize i_size = this->listWidget->iconSize();
+    if (i_size.height()>16){
+        int nSize = i_size.height()-8;
+        this->listWidget->setIconSize(QSize(nSize, nSize));
+    }
+}
+
+
 void PrefixConfigWidget::sortAlpha_Click(){
     if (this->sort_order == D_SORT_TYPE_BY_NAME_ASC){
         this->sort_order = D_SORT_TYPE_BY_NAME_DSC;
