@@ -98,22 +98,14 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
             QString comm_char;
             while (true) {
                 comm_char = in.read(1).toLatin1();
-                if ((comm_char.isNull()) or (comm_char == "\n")){
+                if ((comm_char.isNull()) or (comm_char == "\n") or comm_char.isEmpty()){
                     break;
                 }
-                if (comm_char.isEmpty()){
-                    name.append(" ");
-                } else {
-                    name.append(comm_char);
-                }
+                name.append(comm_char);
             }
-            //Remove args
-            name = name.split(" ")[0];
 #ifdef DEBUG
             qDebug()<<"path: "<<fileInfo.fileName()<<" comm: "<<name;
 #endif
-
-
                 path = "/proc/";
                 path.append(fileInfo.fileName());
                 path.append("/stat");
@@ -124,6 +116,8 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
                     QString line = in.readLine();
                     if (!line.isNull()){
                         // Getting nice and name of the process
+                        // Replace process name in case it contains spaces
+                        line.replace(QRegExp("\\(.*\\)"), "name");
                         nice = line.section(' ', 18, 18);
 
                         //Remove path
@@ -176,7 +170,7 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
 */
 #ifdef _OS_FREEBSD_
     kvm_t *kd;
-    int cntproc, i, ni, ipid;
+    int cntproc, i, ni;
 
     struct kinfo_proc *kp;
     char buf[_POSIX2_LINE_MAX];
@@ -204,7 +198,7 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
     QStringList cur_pids;
     for (i=0; i<cntproc;i++){
         prefix="";
-        ipid = kp[i].ki_pid;
+        int ipid = kp[i].ki_pid;
 
         if (cur_pids.indexOf(QString("%1").arg(ipid))==-1){
             cur_pids << QString("%1").arg(ipid);
@@ -1463,9 +1457,7 @@ QStringList corelib::getCdromDevices(void) const{
 
                 if (!string.isEmpty()){
                     showError(QObject::tr("It seems that the process crashed. STDERR log: %1").arg(string));
-                    delete (&codec);
                 }
-                delete (&codec);
                 return false;
             }
             return true;
@@ -1519,7 +1511,18 @@ QStringList corelib::getCdromDevices(void) const{
             url.append("/documentation/");
             url.append(lang);
             url.append("/");
-            url.append(rawurl);
+            if (rawurl.contains('#')) {
+                QStringList list = rawurl.split('#');
+		url.append(list.at(0));
+	        url.append("?version=");
+	        url.append(APP_VERS);
+		url.append('#');
+		url.append(list.at(1));
+            } else {
+                url.append(rawurl);
+	        url.append("?version=");
+	        url.append(APP_VERS);
+	    }
 
             this->openUrl(url);
             return;
